Machetli
=========

**Machetli** is a Python package for reproducing characteristics of a program (such as bugs) with modified instances. It is meant to be helpful for debugging complex programs and narrowing down where specific behaviors are caused.

Originally, Machetli was developed to be used with the `Fast Downward <http://www.fast-downward.org>`_ planning system. The subpackage **planning** provides a collection of modules for more convenient use with solvers.

**Code**: https://github.com/aibasel/machetli

**Documentation**: https://machetli.readthedocs.io
